Learn R Programming

jarbes (version 2.5.0)

bmeta: Bayesian Meta-Analysis for Combining Studies

Description

This function performers a Bayesian meta-analysis

Usage

bmeta(
  data,
  mean.mu = 0,
  sd.mu = 10,
  scale.sigma.between = 0.5,
  df.scale.between = 1,
  df = 4,
  df.estimate = FALSE,
  df.lower = 3,
  df.upper = 30,
  re = "normal",
  nr.chains = 2,
  nr.iterations = 10000,
  nr.adapt = 1000,
  nr.burnin = 1000,
  nr.thin = 1,
  be.quiet = FALSE,
  parallel = NULL
)

Value

This function returns an object of the class "bmeta". This object contains the MCMC output of each parameter and hyper-parameter in the model and the data frame used for fitting the model.

Arguments

data

A data frame with at least two columns with the following names: 1) TE = treatment effect, 2) seTE = the standard error of the treatment effect.

mean.mu

Prior mean of the overall mean parameter mu, default value is 0.

sd.mu

Prior standard deviation of mu, the default value is 10.

scale.sigma.between

Prior scale parameter for scale gamma distribution for the precision between studies. The default value is 0.5.

df.scale.between

Degrees of freedom of the scale gamma distribution for the precision between studies. The default value is 1, which results in a Half Cauchy distribution for the standard deviation between studies. Larger values e.g. 30 corresponds to a Half Normal distribution.

df

Default value df = 4. When re = "sm", this parameter corresponds to the degrees of freedom of the implied Student-t random effects distribution arising from the scale mixture of normal distributions.

df.estimate

Logical value indicating whether the degrees of freedom parameter of the scale mixture distribution should be estimated. If FALSE the value specified in df is used. Default is FALSE.

df.lower

Lower bound of the prior distribution for the degrees of freedom when df.estimate = TRUE. Default value is 3.

df.upper

Upper bound of the prior distribution for the degrees of freedom when df.estimate = TRUE. Default value is 30.

re

Random effects distribution. Possible values are "normal" for Normal random effects and "sm" for scale mixtures of Normals (robust heavy-tailed model).

nr.chains

Number of chains for the MCMC computations, default 2.

nr.iterations

Number of iterations after adapting the MCMC, default is 10000. Some models may need more iterations.

nr.adapt

Number of iterations in the adaptation process, default is 1000. Some models may need more iterations during adptation.

nr.burnin

Number of iteration discard for burn-in period, default is 1000. Some models may need a longer burnin period.

nr.thin

Thinning rate, it must be a positive integer, the default value 1.

be.quiet

Do not print warning message if the model does not adapt. The default value is FALSE. If you are not sure about the adaptation period choose be.quiet=TRUE.

parallel

NULL -> jags, 'jags.parallel' -> jags.parallel execution

Details

The results of the object of the class bcmeta can be extracted with R2jags or with rjags. In addition a summary, a print and a plot functions are implemented for this type of object.

References

Verde, P.E. (2021) A Bias-Corrected Meta-Analysis Model for Combining Studies of Different Types and Quality. Biometrical Journal; 1–17.