Learn R Programming

jarbes (version 2.4.2)

summary.bcmixmeta: Generic summary function for bcmixmeta object in jarbes.

Description

Generic summary function for bcmixmeta object in jarbes.

Usage

# S3 method for bcmixmeta
summary(object, digits = 3, show.clustering = FALSE, show.neff = FALSE, ...)

Arguments

object

The object generated by the bcmixmeta function.

digits

The number of significant digits printed. The default value is 3.

show.clustering

A logical value indicating whether to show the clustering parameters table. Defaults to `TRUE`.

show.neff

A logical value indicating whether to show the effective sample size column (n.eff) and Rhat. Defaults to `TRUE`.

...

...