Learn R Programming

jarbes (version 2.5.0)

summary.dpmeta: Generic summary function for dpmeta object in jarbes.

Description

Generic summary function for dpmeta object in jarbes.

Usage

# S3 method for dpmeta
summary(
  object,
  digits = 3,
  show.clustering = TRUE,
  show.neff = FALSE,
  max.clusters = 10,
  ...
)

Arguments

object

The object generated by the dpmeta function.

digits

The number of significant digits printed. The default value is 3.

show.clustering

A logical value indicating whether to show the clustering parameters table. Defaults to `TRUE`.

show.neff

A logical value indicating whether to show the effective sample size column (n.eff) and Rhat. Defaults to `TRUE`.

max.clusters

Maximum number of clusters printed in the clustering table. Default is 10.

...

...