This function performers a Bayesian meta-analysis
bmeta(
data,
mean.mu = 0,
sd.mu = 10,
scale.sigma.between = 0.5,
df.scale.between = 1,
df = 4,
df.estimate = FALSE,
df.lower = 3,
df.upper = 30,
re = "normal",
nr.chains = 2,
nr.iterations = 10000,
nr.adapt = 1000,
nr.burnin = 1000,
nr.thin = 1,
be.quiet = FALSE,
parallel = NULL
)This function returns an object of the class "bmeta". This object contains the MCMC output of each parameter and hyper-parameter in the model and the data frame used for fitting the model.
A data frame with at least two columns with the following names: 1) TE = treatment effect, 2) seTE = the standard error of the treatment effect.
Prior mean of the overall mean parameter mu, default value is 0.
Prior standard deviation of mu, the default value is 10.
Prior scale parameter for scale gamma distribution for the precision between studies. The default value is 0.5.
Degrees of freedom of the scale gamma distribution for the precision between studies. The default value is 1, which results in a Half Cauchy distribution for the standard deviation between studies. Larger values e.g. 30 corresponds to a Half Normal distribution.
Default value df = 4. When re = "sm", this parameter corresponds to the degrees of freedom of the implied Student-t random effects distribution arising from the scale mixture of normal distributions.
Logical value indicating whether the degrees of freedom parameter
of the scale mixture distribution should be estimated. If FALSE
the value specified in df is used. Default is FALSE.
Lower bound of the prior distribution for the degrees of freedom
when df.estimate = TRUE. Default value is 3.
Upper bound of the prior distribution for the degrees of freedom
when df.estimate = TRUE. Default value is 30.
Random effects distribution. Possible values are "normal" for Normal random effects and "sm" for scale mixtures of Normals (robust heavy-tailed model).
Number of chains for the MCMC computations, default 2.
Number of iterations after adapting the MCMC, default is 10000. Some models may need more iterations.
Number of iterations in the adaptation process, default is 1000. Some models may need more iterations during adptation.
Number of iteration discard for burn-in period, default is 1000. Some models may need a longer burnin period.
Thinning rate, it must be a positive integer, the default value 1.
Do not print warning message if the model does not adapt. The default value is FALSE. If you are not sure about the adaptation period choose be.quiet=TRUE.
NULL -> jags, 'jags.parallel' -> jags.parallel execution
The results of the object of the class bcmeta can be extracted with R2jags or with rjags. In addition a summary, a print and a plot functions are implemented for this type of object.
Verde, P.E. (2021) A Bias-Corrected Meta-Analysis Model for Combining Studies of Different Types and Quality. Biometrical Journal; 1–17.