This function is built with `ggplot2`. Parameters such as `binwidth`, `adjust`, `density.color`, `density.lwd`, and `density.lty` correspond directly to arguments in the `ggplot2` geoms.
# S3 method for bcmixmeta
plot(
x,
plot.type = "predictive_with_bias",
n.samples = NULL,
x.lim = NULL,
y.lim = NULL,
x.lab = NULL,
y.lab = "Posterior Predictive Distribution",
title.plot = NULL,
show.histogram = TRUE,
show.rug = TRUE,
show.legend = FALSE,
binwidth = 0.08,
adjust = 1,
predictive.color = "blue",
mu.color = "black",
bias.color = "red",
hist.color = "black",
hist.fill = "grey95",
rug.color = "green",
rug.alpha = 1,
density.alpha = 0.4,
density.lwd = 1,
density.lty = 1,
...
)The object generated by the bcmixmeta function (the BC-BNP model output).
A character string specifying the type of plot: "predictive_with_bias" (default), "predictive", "mu_posterior", "tau_posterior".
The number of posterior samples to plot. If NULL, all posterior samples are used.
Numeric vector of length 2 specifying the x-axis limits.
Numeric vector of length 2 specifying the y-axis limits.
Text with the label of the x-axis.
Text with the label of the y-axis.
Text for setting a title in the plot.
A logical value indicating whether to show the histogram.
A logical value indicating whether to show the rug plot.
A logical value indicating whether to display the legend.
A numeric value specifying the bin width for the histogram.
A numeric value to adjust the bandwidth of the density curves.
A character value specifying the color of the posterior predictive density curve.
A character value specifying the color of the posterior mean density curve.
A character value specifying the color of the bias-adjusted mean density curve.
A character value for the histogram border color.
A character value for the histogram fill color.
A character value for the rug plot color.
A numeric value between 0 and 1 specifying the rug plot transparency.
A numeric value between 0 and 1 specifying density transparency.
A numeric value specifying density line width.
A numeric value specifying density line type.
...