Generic summary function for bcmixmeta object in jarbes.
# S3 method for bcmixmeta
summary(object, digits = 3, show.clustering = FALSE, show.neff = FALSE, ...)The object generated by the bcmixmeta function.
The number of significant digits printed. The default value is 3.
A logical value indicating whether to show the clustering parameters table. Defaults to `TRUE`.
A logical value indicating whether to show the effective sample size column (n.eff) and Rhat. Defaults to `TRUE`.
...