Generic summary function for dpmeta object in jarbes.
# S3 method for dpmeta
summary(
object,
digits = 3,
show.clustering = TRUE,
show.neff = FALSE,
max.clusters = 10,
...
)The object generated by the dpmeta function.
The number of significant digits printed. The default value is 3.
A logical value indicating whether to show the clustering parameters table. Defaults to `TRUE`.
A logical value indicating whether to show the effective sample size column (n.eff) and Rhat. Defaults to `TRUE`.
Maximum number of clusters printed in the clustering table. Default is 10.
...